@@ -6,7 +6,6 @@ from dotenv import load_dotenv
 from selenium import webdriver
 from selenium.common.exceptions import WebDriverException
 from selenium.webdriver.chrome.options import Options
-from selenium.webdriver.chrome.service import Service
 
 from econuy.utils import get_project_root
 
@@ -19,9 +18,10 @@ def _build():
     chrome_options.add_argument("--no-sandbox")
     try:
         load_dotenv(Path(get_project_root(), ".env"))
-        service = Service(executable_path=os.environ.get("CHROMEDRIVER_PATH"))
         chrome_options.binary_location = os.environ.get("GOOGLE_CHROME_PATH")
-        return webdriver.Chrome(options=chrome_options, service=service)
+        return webdriver.Chrome(
+            executable_path=os.environ.get("CHROMEDRIVER_PATH"),
+            options=chrome_options)
     except (WebDriverException, TypeError):
         chromedriver_autoinstaller.install()
         return webdriver.Chrome(options=chrome_options)
