@@ -9,7 +9,6 @@ import pytest
 from sqlalchemy import create_engine, inspect
 
 from econuy import transform
-from econuy.retrieval import nxr
 from econuy.session import Session
 from econuy.utils import metadata, sqlutil
 from econuy.utils.lstrings import fiscal_metadata
@@ -19,12 +18,12 @@ except ImportError:
     from .test_transform import dummy_df
 
 CUR_DIR = path.abspath(path.dirname(__file__))
-TEST_DIR = path.join(path.dirname(CUR_DIR), "test-data")
+TEST_DIR = path.join(CUR_DIR, "test-data")
 TEST_CON = create_engine("sqlite://").connect()
 sqlutil.insert_csvs(con=TEST_CON, directory=TEST_DIR)
 
 
-def remove_clutter(avoid: Tuple[str] = ("reserves_chg.csv",
+def remove_clutter(avoid: Tuple[str] = ("reserves_changes.csv",
                                         "commodity_weights.csv",
                                         "nxr_daily.csv")):
     [remove(path.join(TEST_DIR, x)) for x in listdir(TEST_DIR)
@@ -42,7 +41,7 @@ def test_prices_inflation():
     session = Session(location=TEST_CON)
     assert isinstance(session, Session)
     assert isinstance(session.dataset, pd.DataFrame)
-    measures = session.get_custom(dataset="price_measures").dataset
+    measures = session.get_custom(dataset="cpi_measures").dataset
     remove_clutter()
     prices = session.get(dataset="cpi").dataset
     prices = prices.loc[prices.index >= "1997-03-31"]
@@ -58,10 +57,9 @@ def test_fiscal():
     session = Session(location=TEST_CON)
     assert isinstance(session, Session)
     assert isinstance(session.dataset, pd.DataFrame)
-    fiscal_tfm = session.get_custom(dataset="fiscal", aggregation="nfps",
-                                    fss=True, unit="gdp").dataset
+    fiscal_tfm = session.get_custom(dataset="balance_fss").dataset
     remove_clutter()
-    fiscal_ = session.get(dataset="fiscal").dataset
+    fiscal_ = session.get(dataset="balance").dataset
     nfps = fiscal_["nfps"]
     gc = fiscal_["gc-bps"]
     proc = pd.DataFrame(index=nfps.index)
@@ -98,46 +96,12 @@ def test_fiscal():
     metadata._set(compare, area="Sector público",
                   currency="UYU", inf_adj="No", unit="No",
                   seas_adj="NSA", ts_type="Flujo", cumperiods=1)
-    compare_gdp = transform.rolling(compare, periods=12, operation="sum")
-    compare_gdp = transform.convert_gdp(compare_gdp)
-    compare_gdp.columns = fiscal_tfm.columns
-    assert compare_gdp.equals(fiscal_tfm)
+    compare.columns = fiscal_tfm["balance_fss_nfps_fssadj"].columns
+    assert compare.equals(fiscal_tfm["balance_fss_nfps_fssadj"])
     remove_clutter()
-    fiscal_tfm = session.get_custom(dataset="fiscal", aggregation="nfps",
-                                    fss=True, unit="usd").dataset
-    compare_usd = transform.convert_usd(compare)
-    compare_usd.columns = fiscal_tfm.columns
-    assert compare_usd.equals(fiscal_tfm)
-    remove_clutter()
-    fiscal_tfm = session.get_custom(dataset="fiscal", aggregation="nfps",
-                                    fss=True, unit="real").dataset
-    compare_real = transform.convert_real(compare)
-    compare_real.columns = fiscal_tfm.columns
-    assert compare_real.equals(fiscal_tfm)
-    remove_clutter()
-    start_date = "2010-01-31"
-    end_date = "2010-12-31"
-    fiscal_tfm = session.get_custom(dataset="fiscal", aggregation="nfps",
-                                    fss=True, unit="real_usd",
-                                    start_date=start_date,
-                                    end_date=end_date).dataset
-    compare_real_usd = transform.convert_real(compare, start_date=start_date,
-                                              end_date=end_date)
-    xr = nxr.get_monthly(update_loc=None, save_loc=None)
-    compare_real_usd = compare_real_usd.divide(
-        xr[start_date:end_date].mean()[1])
-    compare_real_usd.columns = fiscal_tfm.columns
-    assert compare_real_usd.equals(fiscal_tfm)
-    remove_clutter()
-    with pytest.raises(ValueError):
-        session.get_custom(dataset="fiscal", aggregation="nfps",
-                           unit="wrong")
-    with pytest.raises(ValueError):
-        session.get_custom(dataset="fiscal", aggregation="wrong")
-    remove_clutter()
-    fiscal_ = session.get(dataset="fiscal").dataset
+    fiscal_ = session.get(dataset="balance").dataset
     session.only_get = True
-    compare = session.get(dataset="fiscal").dataset
+    compare = session.get(dataset="balance").dataset
     for v, v2 in zip(fiscal_.values(), compare.values()):
         assert v.round(4).equals(v2.round(4))
     remove_clutter()
@@ -149,42 +113,26 @@ def test_labor():
     session = Session(location=TEST_CON)
     assert isinstance(session, Session)
     assert isinstance(session.dataset, pd.DataFrame)
-    labor_tfm = session.get_custom(dataset="labor", seas_adj="trend",
-                                   extend=False).dataset
-    labor_tfm = labor_tfm.iloc[:, [0, 1, 2]]
+    labor_tfm = session.get_custom(dataset="rates_people").dataset
+    labor_tfm = labor_tfm.iloc[:, [0, 1, 2]].loc[labor_tfm.index >= "2006-01-01"]
     remove_clutter()
     labor_ = session.get(dataset="labor").dataset.iloc[:, [0, 3, 6]]
     session.only_get = True
     compare = session.get(dataset="labor").dataset.iloc[:, [0, 3, 6]]
-    compare = transform.decompose(compare, flavor="trend")
     compare.columns = labor_tfm.columns
     assert labor_tfm.round(4).equals(compare.round(4))
     remove_clutter()
-    session.only_get = False
-    labor_trend, labor_sa = transform.decompose(labor_, outlier=True,
-                                                trading=True)
-    labor_trend.columns = labor_tfm.columns
-    assert labor_trend.equals(labor_tfm)
-    remove_clutter()
-    labor_tfm = session.get_custom(dataset="labor", seas_adj="seas",
-                                   extend=False).dataset
-    labor_tfm = labor_tfm.iloc[:, [0, 1, 2]]
-    labor_sa.columns = labor_tfm.columns
-    assert labor_sa.equals(labor_tfm)
-    remove_clutter()
-    labor_tfm = session.get_custom(dataset="labor", seas_adj=None,
-                                   extend=False).dataset
+    labor_tfm = session.get_custom(dataset="rates_people").dataset
+    labor_tfm = labor_tfm.loc[labor_tfm.index >= "2006-01-01"]
     compare = labor_.iloc[:, 0].div(labor_.iloc[:, 1]).round(4)
     compare_2 = labor_tfm.iloc[:, 3].div(labor_tfm.iloc[:, 4]).round(4)
     assert compare.equals(compare_2)
     compare = labor_tfm.iloc[:, 3].mul(labor_.iloc[:, 2]).div(100).round(4)
     assert compare.equals(labor_tfm.iloc[:, 5].round(4))
     remove_clutter()
-    labor_ext = session.get_custom(dataset="labor", extend=True).dataset
+    labor_ext = session.get_custom(dataset="rates_people").dataset
     assert len(labor_ext) > len(labor_tfm)
     remove_clutter()
-    with pytest.raises(ValueError):
-        session.get_custom(dataset="labor", seas_adj="wrong")
 
 
 def test_wages():
@@ -192,37 +140,12 @@ def test_wages():
     session = Session(location=TEST_CON)
     assert isinstance(session, Session)
     assert isinstance(session.dataset, pd.DataFrame)
-    full_wages = session.get_custom(dataset="real_wages",
-                                    seas_adj="trend").dataset
-    wages_tfm = full_wages.iloc[:, [0, 1, 2]]
-    remove_clutter()
-    wages_ = session.get(dataset="wages").dataset
-    session.only_get = True
-    compare = session.get(dataset="wages").dataset
-    assert wages_.round(4).equals(compare.round(4))
-    session.only_get = False
-    remove_clutter()
-    wages_trend, wages_sa = transform.decompose(wages_, outlier=False,
-                                                trading=True)
-    wages_trend = transform.base_index(wages_trend, start_date="2008-07-31")
-    wages_trend.columns = wages_tfm.columns
-    assert wages_trend.equals(wages_tfm)
-    remove_clutter()
-    full_wages = session.get_custom(dataset="wages", seas_adj="seas").dataset
-    wages_tfm = full_wages.iloc[:, [0, 1, 2]]
-    wages_sa = transform.base_index(wages_sa, start_date="2008-07-31")
-    wages_sa.columns = wages_tfm.columns
-    assert wages_sa.equals(wages_tfm)
-    remove_clutter()
-    full_wages = session.get_custom(dataset="wages", seas_adj=None).dataset
-    real_wages = full_wages.iloc[:, [3, 4, 5]]
-    compare = transform.convert_real(wages_)
+    real_wages = session.get(dataset="real_wages").dataset
+    nominal_wages = session.get(dataset="wages").dataset
+    compare = transform.convert_real(nominal_wages, update_loc=TEST_CON)
     compare = transform.base_index(compare, start_date="2008-07-31")
     compare.columns = real_wages.columns
-    assert real_wages.equals(compare)
-    remove_clutter()
-    with pytest.raises(ValueError):
-        session.get_custom(dataset="wages", seas_adj="wrong")
+    assert compare.equals(real_wages)
 
 
 def test_naccounts():
@@ -230,7 +153,7 @@ def test_naccounts():
     session = Session(location=TEST_CON)
     assert isinstance(session, Session)
     assert isinstance(session.dataset, pd.DataFrame)
-    na_ = session.get(dataset="na").dataset
+    na_ = session.get(dataset="naccounts").dataset
     assert isinstance(na_, dict)
     assert len(na_) == 6
     remove_clutter()
@@ -261,7 +184,7 @@ def test_rates():
     session = Session(location=TEST_CON)
     assert isinstance(session, Session)
     assert isinstance(session.dataset, pd.DataFrame)
-    rates = session.get(dataset="rates").dataset
+    rates = session.get(dataset="interest_rates").dataset
     assert rates.index[0] == dt.datetime(1998, 1, 31)
     remove_clutter()
 
@@ -288,6 +211,17 @@ def test_call():
     remove_clutter()
 
 
+def test_hours():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    hours = session.get(dataset="hours").dataset
+    assert hours.index[0] == dt.datetime(2006, 1, 31)
+    assert len(hours.columns) == 17
+    remove_clutter()
+
+
 def test_bonds():
     remove_clutter()
     session = Session(location=TEST_CON)
@@ -298,6 +232,81 @@ def test_bonds():
     remove_clutter()
 
 
+def test_income():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    household = session.get(dataset="household_income").dataset
+    assert household.index[0] == dt.datetime(2006, 1, 31)
+    assert len(household.columns) == 5
+    remove_clutter()
+    capita = session.get(dataset="capita_income").dataset
+    assert capita.index[0] == dt.datetime(2006, 1, 31)
+    assert len(capita.columns) == 5
+    remove_clutter()
+
+
+def test_sectors():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    cattle = session.get(dataset="cattle").dataset
+    assert cattle.index[0] == dt.datetime(2005, 1, 2)
+    assert len(cattle.columns) == 6
+    remove_clutter()
+    milk = session.get(dataset="milk").dataset
+    assert milk.index[0] == dt.datetime(2002, 1, 31)
+    assert len(milk.columns) == 1
+    remove_clutter()
+    cement = session.get(dataset="cement").dataset
+    assert cement.index[0] == dt.datetime(1990, 1, 31)
+    assert len(cement.columns) == 3
+    remove_clutter()
+
+
+def test_energy():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    diesel = session.get(dataset="diesel").dataset
+    assert diesel.index[0] == dt.datetime(2004, 1, 31)
+    assert len(diesel.columns) == 21
+    remove_clutter()
+    gasoline = session.get(dataset="gasoline").dataset
+    assert gasoline.index[0] == dt.datetime(2004, 1, 31)
+    assert len(gasoline.columns) == 21
+    remove_clutter()
+    electricity = session.get(dataset="electricity").dataset
+    assert electricity.index[0] == dt.datetime(2000, 1, 31)
+    assert len(electricity.columns) == 8
+    remove_clutter()
+
+
+def test_confidence():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    consumer = session.get(dataset="consumer_confidence").dataset
+    assert consumer.index[0] == dt.datetime(2007, 8, 31)
+    assert len(consumer.columns) == 4
+    remove_clutter()
+
+
+def test_bond_index():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    risk = session.get(dataset="sovereign_risk").dataset
+    assert risk.index[0] == dt.datetime(1999, 1, 1)
+    assert len(risk.columns) == 1
+    remove_clutter()
+
+
 def test_trade():
     remove_clutter()
     session = Session(location=TEST_CON)
@@ -308,28 +317,17 @@ def test_trade():
     assert len(tb_) == 12
     remove_clutter()
     net = session.get_custom(dataset="net_trade").dataset
-    compare = (tb_["tb_x_dest_val"].
+    compare = (tb_["trade_x_dest_val"].
                rename(columns={"Total exportaciones": "Total"})
-               - tb_["tb_m_orig_val"].
+               - tb_["trade_m_orig_val"].
                rename(columns={"Total importaciones": "Total"}))
     compare.columns = net.columns
     assert net.equals(compare)
     remove_clutter()
-
-
-def test_tot():
-    remove_clutter()
-    session = Session(location=TEST_CON)
-    assert isinstance(session, Session)
-    assert isinstance(session.dataset, pd.DataFrame)
-    tb_ = session.get(dataset="trade").dataset
-    assert isinstance(tb_, dict)
-    assert len(tb_) == 12
-    remove_clutter()
-    net = session.get_custom(dataset="tot").dataset
-    compare = (tb_["tb_x_dest_pri"].
+    net = session.get_custom(dataset="terms_of_trade").dataset
+    compare = (tb_["trade_x_dest_pri"].
                rename(columns={"Total exportaciones": "Total"})
-               / tb_["tb_m_orig_pri"].
+               / tb_["trade_m_orig_pri"].
                rename(columns={"Total importaciones": "Total"}))
     compare = compare.loc[:, ["Total"]]
     compare = transform.base_index(compare, start_date="2005-01-01",
@@ -387,7 +385,7 @@ def test_edge():
     session = Session(location="new_dir")
     assert path.isdir("new_dir")
     shutil.rmtree(session.location)
-    Session(location=TEST_DIR).get_custom(dataset="price_measures",
+    Session(location=TEST_DIR).get_custom(dataset="cpi_measures",
                                           update=False, save=False)
     remove_clutter()
 
